# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!   # noqa: E501

    The version of the OpenAPI document: 0.4.16
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import carbon3d
from carbon3d.api.models_api import ModelsApi  # noqa: E501
from carbon3d.rest import ApiException


class TestModelsApi(unittest.TestCase):
    """ModelsApi unit test stubs"""

    def setUp(self):
        self.api = carbon3d.api.models_api.ModelsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_download_model(self):
        """Test case for download_model

        Download a model by UUID  # noqa: E501
        """
        pass

    def test_find_models(self):
        """Test case for find_models

        Fetch models  # noqa: E501
        """
        pass

    def test_get_model(self):
        """Test case for get_model

        Get a model by UUID  # noqa: E501
        """
        pass

    def test_get_presigned_upload_url(self):
        """Test case for get_presigned_upload_url

        Create presigned upload URL for a filename  # noqa: E501
        """
        pass

    def test_resolve_presigned_model_upload(self):
        """Test case for resolve_presigned_model_upload

        Resolve presigned model upload  # noqa: E501
        """
        pass

    def test_upload_model(self):
        """Test case for upload_model

        Upload a model  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!   # noqa: E501

    The version of the OpenAPI document: 0.4.16
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from carbon3d.configuration import Configuration


class Model(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'uuid': 'str',
        'filename': 'str',
        'external_id': 'str',
        'application_uuid': 'str',
        'description': 'str',
        'file_size_bytes': 'int',
        'updated_at': 'str',
        'created_at': 'str',
        'created_by': 'str'
    }

    attribute_map = {
        'uuid': 'uuid',
        'filename': 'filename',
        'external_id': 'external_id',
        'application_uuid': 'application_uuid',
        'description': 'description',
        'file_size_bytes': 'file_size_bytes',
        'updated_at': 'updated_at',
        'created_at': 'created_at',
        'created_by': 'created_by'
    }

    def __init__(self, uuid=None, filename=None, external_id=None, application_uuid=None, description=None, file_size_bytes=None, updated_at=None, created_at=None, created_by=None, local_vars_configuration=None):  # noqa: E501
        """Model - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._uuid = None
        self._filename = None
        self._external_id = None
        self._application_uuid = None
        self._description = None
        self._file_size_bytes = None
        self._updated_at = None
        self._created_at = None
        self._created_by = None
        self.discriminator = None

        self.uuid = uuid
        self.filename = filename
        if external_id is not None:
            self.external_id = external_id
        if application_uuid is not None:
            self.application_uuid = application_uuid
        if description is not None:
            self.description = description
        if file_size_bytes is not None:
            self.file_size_bytes = file_size_bytes
        if updated_at is not None:
            self.updated_at = updated_at
        if created_at is not None:
            self.created_at = created_at
        if created_by is not None:
            self.created_by = created_by

    @property
    def uuid(self):
        """Gets the uuid of this Model.  # noqa: E501

        Generated unique identifier  # noqa: E501

        :return: The uuid of this Model.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this Model.

        Generated unique identifier  # noqa: E501

        :param uuid: The uuid of this Model.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and uuid is None:  # noqa: E501
            raise ValueError("Invalid value for `uuid`, must not be `None`")  # noqa: E501

        self._uuid = uuid

    @property
    def filename(self):
        """Gets the filename of this Model.  # noqa: E501

        Filename of the model  # noqa: E501

        :return: The filename of this Model.  # noqa: E501
        :rtype: str
        """
        return self._filename

    @filename.setter
    def filename(self, filename):
        """Sets the filename of this Model.

        Filename of the model  # noqa: E501

        :param filename: The filename of this Model.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and filename is None:  # noqa: E501
            raise ValueError("Invalid value for `filename`, must not be `None`")  # noqa: E501

        self._filename = filename

    @property
    def external_id(self):
        """Gets the external_id of this Model.  # noqa: E501

        External id provided by user  # noqa: E501

        :return: The external_id of this Model.  # noqa: E501
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this Model.

        External id provided by user  # noqa: E501

        :param external_id: The external_id of this Model.  # noqa: E501
        :type: str
        """

        self._external_id = external_id

    @property
    def application_uuid(self):
        """Gets the application_uuid of this Model.  # noqa: E501

        Application UUID  # noqa: E501

        :return: The application_uuid of this Model.  # noqa: E501
        :rtype: str
        """
        return self._application_uuid

    @application_uuid.setter
    def application_uuid(self, application_uuid):
        """Sets the application_uuid of this Model.

        Application UUID  # noqa: E501

        :param application_uuid: The application_uuid of this Model.  # noqa: E501
        :type: str
        """

        self._application_uuid = application_uuid

    @property
    def description(self):
        """Gets the description of this Model.  # noqa: E501

        Description of the model  # noqa: E501

        :return: The description of this Model.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Model.

        Description of the model  # noqa: E501

        :param description: The description of this Model.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def file_size_bytes(self):
        """Gets the file_size_bytes of this Model.  # noqa: E501

        Model file size in bytes  # noqa: E501

        :return: The file_size_bytes of this Model.  # noqa: E501
        :rtype: int
        """
        return self._file_size_bytes

    @file_size_bytes.setter
    def file_size_bytes(self, file_size_bytes):
        """Sets the file_size_bytes of this Model.

        Model file size in bytes  # noqa: E501

        :param file_size_bytes: The file_size_bytes of this Model.  # noqa: E501
        :type: int
        """

        self._file_size_bytes = file_size_bytes

    @property
    def updated_at(self):
        """Gets the updated_at of this Model.  # noqa: E501

        Timestamp at which the model was last updated  # noqa: E501

        :return: The updated_at of this Model.  # noqa: E501
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Model.

        Timestamp at which the model was last updated  # noqa: E501

        :param updated_at: The updated_at of this Model.  # noqa: E501
        :type: str
        """

        self._updated_at = updated_at

    @property
    def created_at(self):
        """Gets the created_at of this Model.  # noqa: E501

        Timestamp at which the model was created  # noqa: E501

        :return: The created_at of this Model.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Model.

        Timestamp at which the model was created  # noqa: E501

        :param created_at: The created_at of this Model.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def created_by(self):
        """Gets the created_by of this Model.  # noqa: E501

        Name of the model creator  # noqa: E501

        :return: The created_by of this Model.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this Model.

        Name of the model creator  # noqa: E501

        :param created_by: The created_by of this Model.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Model):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Model):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!   # noqa: E501

    The version of the OpenAPI document: 0.4.16
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from carbon3d.configuration import Configuration


class Part(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'uuid': 'str',
        'part_number': 'str',
        'model_uuid': 'str',
        'description': 'str',
        'part_tags': 'dict(str, str)',
        'part_number_tags': 'dict(str, str)'
    }

    attribute_map = {
        'uuid': 'uuid',
        'part_number': 'part_number',
        'model_uuid': 'model_uuid',
        'description': 'description',
        'part_tags': 'part_tags',
        'part_number_tags': 'part_number_tags'
    }

    def __init__(self, uuid=None, part_number=None, model_uuid=None, description=None, part_tags=None, part_number_tags=None, local_vars_configuration=None):  # noqa: E501
        """Part - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._uuid = None
        self._part_number = None
        self._model_uuid = None
        self._description = None
        self._part_tags = None
        self._part_number_tags = None
        self.discriminator = None

        self.uuid = uuid
        self.part_number = part_number
        if model_uuid is not None:
            self.model_uuid = model_uuid
        if description is not None:
            self.description = description
        if part_tags is not None:
            self.part_tags = part_tags
        if part_number_tags is not None:
            self.part_number_tags = part_number_tags

    @property
    def uuid(self):
        """Gets the uuid of this Part.  # noqa: E501

        Part UUID  # noqa: E501

        :return: The uuid of this Part.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this Part.

        Part UUID  # noqa: E501

        :param uuid: The uuid of this Part.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and uuid is None:  # noqa: E501
            raise ValueError("Invalid value for `uuid`, must not be `None`")  # noqa: E501

        self._uuid = uuid

    @property
    def part_number(self):
        """Gets the part_number of this Part.  # noqa: E501

        Part Number  # noqa: E501

        :return: The part_number of this Part.  # noqa: E501
        :rtype: str
        """
        return self._part_number

    @part_number.setter
    def part_number(self, part_number):
        """Sets the part_number of this Part.

        Part Number  # noqa: E501

        :param part_number: The part_number of this Part.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and part_number is None:  # noqa: E501
            raise ValueError("Invalid value for `part_number`, must not be `None`")  # noqa: E501

        self._part_number = part_number

    @property
    def model_uuid(self):
        """Gets the model_uuid of this Part.  # noqa: E501

        Model UUID  # noqa: E501

        :return: The model_uuid of this Part.  # noqa: E501
        :rtype: str
        """
        return self._model_uuid

    @model_uuid.setter
    def model_uuid(self, model_uuid):
        """Sets the model_uuid of this Part.

        Model UUID  # noqa: E501

        :param model_uuid: The model_uuid of this Part.  # noqa: E501
        :type: str
        """

        self._model_uuid = model_uuid

    @property
    def description(self):
        """Gets the description of this Part.  # noqa: E501


        :return: The description of this Part.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Part.


        :param description: The description of this Part.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def part_tags(self):
        """Gets the part_tags of this Part.  # noqa: E501

        Key value pairs to be associated with part  # noqa: E501

        :return: The part_tags of this Part.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._part_tags

    @part_tags.setter
    def part_tags(self, part_tags):
        """Sets the part_tags of this Part.

        Key value pairs to be associated with part  # noqa: E501

        :param part_tags: The part_tags of this Part.  # noqa: E501
        :type: dict(str, str)
        """

        self._part_tags = part_tags

    @property
    def part_number_tags(self):
        """Gets the part_number_tags of this Part.  # noqa: E501

        Key value pairs to be associated with part number  # noqa: E501

        :return: The part_number_tags of this Part.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._part_number_tags

    @part_number_tags.setter
    def part_number_tags(self, part_number_tags):
        """Sets the part_number_tags of this Part.

        Key value pairs to be associated with part number  # noqa: E501

        :param part_number_tags: The part_number_tags of this Part.  # noqa: E501
        :type: dict(str, str)
        """

        self._part_number_tags = part_number_tags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Part):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Part):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!   # noqa: E501

    The version of the OpenAPI document: 0.4.16
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import carbon3d
from carbon3d.api.parts_api import PartsApi  # noqa: E501
from carbon3d.rest import ApiException


class TestPartsApi(unittest.TestCase):
    """PartsApi unit test stubs"""

    def setUp(self):
        self.api = carbon3d.api.parts_api.PartsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_part(self):
        """Test case for create_part

        Create a Part  # noqa: E501
        """
        pass

    def test_get_part(self):
        """Test case for get_part

        Fetch a Part  # noqa: E501
        """
        pass

    def test_get_parts(self):
        """Test case for get_parts

        Fetch parts  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!   # noqa: E501

    The version of the OpenAPI document: 0.4.16
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from carbon3d.configuration import Configuration


class PartMeasurement(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'uuid': 'str',
        'printed_part_uuid': 'str',
        'part_measurement_template_uuid': 'str',
        'value': 'float',
        'category_value': 'str',
        'updated_at': 'datetime',
        'measurement_result': 'str',
        'zones': 'list[str]',
        'notes': 'str'
    }

    attribute_map = {
        'uuid': 'uuid',
        'printed_part_uuid': 'printed_part_uuid',
        'part_measurement_template_uuid': 'part_measurement_template_uuid',
        'value': 'value',
        'category_value': 'category_value',
        'updated_at': 'updated_at',
        'measurement_result': 'measurement_result',
        'zones': 'zones',
        'notes': 'notes'
    }

    def __init__(self, uuid=None, printed_part_uuid=None, part_measurement_template_uuid=None, value=None, category_value=None, updated_at=None, measurement_result=None, zones=None, notes=None, local_vars_configuration=None):  # noqa: E501
        """PartMeasurement - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._uuid = None
        self._printed_part_uuid = None
        self._part_measurement_template_uuid = None
        self._value = None
        self._category_value = None
        self._updated_at = None
        self._measurement_result = None
        self._zones = None
        self._notes = None
        self.discriminator = None

        if uuid is not None:
            self.uuid = uuid
        if printed_part_uuid is not None:
            self.printed_part_uuid = printed_part_uuid
        if part_measurement_template_uuid is not None:
            self.part_measurement_template_uuid = part_measurement_template_uuid
        self.value = value
        self.category_value = category_value
        if updated_at is not None:
            self.updated_at = updated_at
        if measurement_result is not None:
            self.measurement_result = measurement_result
        if zones is not None:
            self.zones = zones
        if notes is not None:
            self.notes = notes

    @property
    def uuid(self):
        """Gets the uuid of this PartMeasurement.  # noqa: E501

        The uuid of the part measurement  # noqa: E501

        :return: The uuid of this PartMeasurement.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this PartMeasurement.

        The uuid of the part measurement  # noqa: E501

        :param uuid: The uuid of this PartMeasurement.  # noqa: E501
        :type: str
        """

        self._uuid = uuid

    @property
    def printed_part_uuid(self):
        """Gets the printed_part_uuid of this PartMeasurement.  # noqa: E501

        The uuid of the printed part  # noqa: E501

        :return: The printed_part_uuid of this PartMeasurement.  # noqa: E501
        :rtype: str
        """
        return self._printed_part_uuid

    @printed_part_uuid.setter
    def printed_part_uuid(self, printed_part_uuid):
        """Sets the printed_part_uuid of this PartMeasurement.

        The uuid of the printed part  # noqa: E501

        :param printed_part_uuid: The printed_part_uuid of this PartMeasurement.  # noqa: E501
        :type: str
        """

        self._printed_part_uuid = printed_part_uuid

    @property
    def part_measurement_template_uuid(self):
        """Gets the part_measurement_template_uuid of this PartMeasurement.  # noqa: E501

        The uuid of the part measurement template  # noqa: E501

        :return: The part_measurement_template_uuid of this PartMeasurement.  # noqa: E501
        :rtype: str
        """
        return self._part_measurement_template_uuid

    @part_measurement_template_uuid.setter
    def part_measurement_template_uuid(self, part_measurement_template_uuid):
        """Sets the part_measurement_template_uuid of this PartMeasurement.

        The uuid of the part measurement template  # noqa: E501

        :param part_measurement_template_uuid: The part_measurement_template_uuid of this PartMeasurement.  # noqa: E501
        :type: str
        """

        self._part_measurement_template_uuid = part_measurement_template_uuid

    @property
    def value(self):
        """Gets the value of this PartMeasurement.  # noqa: E501

        Numerical value of a measurement (e.g. 5, 131.24)  # noqa: E501

        :return: The value of this PartMeasurement.  # noqa: E501
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this PartMeasurement.

        Numerical value of a measurement (e.g. 5, 131.24)  # noqa: E501

        :param value: The value of this PartMeasurement.  # noqa: E501
        :type: float
        """

        self._value = value

    @property
    def category_value(self):
        """Gets the category_value of this PartMeasurement.  # noqa: E501

        Category value of a measurement (e.g. tear, long, etc.)  # noqa: E501

        :return: The category_value of this PartMeasurement.  # noqa: E501
        :rtype: str
        """
        return self._category_value

    @category_value.setter
    def category_value(self, category_value):
        """Sets the category_value of this PartMeasurement.

        Category value of a measurement (e.g. tear, long, etc.)  # noqa: E501

        :param category_value: The category_value of this PartMeasurement.  # noqa: E501
        :type: str
        """

        self._category_value = category_value

    @property
    def updated_at(self):
        """Gets the updated_at of this PartMeasurement.  # noqa: E501

        Time when the measurement was taken  # noqa: E501

        :return: The updated_at of this PartMeasurement.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this PartMeasurement.

        Time when the measurement was taken  # noqa: E501

        :param updated_at: The updated_at of this PartMeasurement.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def measurement_result(self):
        """Gets the measurement_result of this PartMeasurement.  # noqa: E501

        Result of the measurement  # noqa: E501

        :return: The measurement_result of this PartMeasurement.  # noqa: E501
        :rtype: str
        """
        return self._measurement_result

    @measurement_result.setter
    def measurement_result(self, measurement_result):
        """Sets the measurement_result of this PartMeasurement.

        Result of the measurement  # noqa: E501

        :param measurement_result: The measurement_result of this PartMeasurement.  # noqa: E501
        :type: str
        """
        allowed_values = ["pass", "fail", "flag", "incomplete"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and measurement_result not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `measurement_result` ({0}), must be one of {1}"  # noqa: E501
                .format(measurement_result, allowed_values)
            )

        self._measurement_result = measurement_result

    @property
    def zones(self):
        """Gets the zones of this PartMeasurement.  # noqa: E501

        Array of zones where category value applies (e.g. front, side)  # noqa: E501

        :return: The zones of this PartMeasurement.  # noqa: E501
        :rtype: list[str]
        """
        return self._zones

    @zones.setter
    def zones(self, zones):
        """Sets the zones of this PartMeasurement.

        Array of zones where category value applies (e.g. front, side)  # noqa: E501

        :param zones: The zones of this PartMeasurement.  # noqa: E501
        :type: list[str]
        """

        self._zones = zones

    @property
    def notes(self):
        """Gets the notes of this PartMeasurement.  # noqa: E501

        Notes associated with measurement  # noqa: E501

        :return: The notes of this PartMeasurement.  # noqa: E501
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """Sets the notes of this PartMeasurement.

        Notes associated with measurement  # noqa: E501

        :param notes: The notes of this PartMeasurement.  # noqa: E501
        :type: str
        """

        self._notes = notes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PartMeasurement):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PartMeasurement):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!   # noqa: E501

    The version of the OpenAPI document: 0.4.16
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from carbon3d.configuration import Configuration


class PartMeasurementTemplateResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'limit': 'int',
        'next_cursor': 'str',
        'total_count': 'int',
        'part_measurement_templates': 'list[PartMeasurementTemplate]'
    }

    attribute_map = {
        'limit': 'limit',
        'next_cursor': 'next_cursor',
        'total_count': 'total_count',
        'part_measurement_templates': 'part_measurement_templates'
    }

    def __init__(self, limit=None, next_cursor=None, total_count=None, part_measurement_templates=None, local_vars_configuration=None):  # noqa: E501
        """PartMeasurementTemplateResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._limit = None
        self._next_cursor = None
        self._total_count = None
        self._part_measurement_templates = None
        self.discriminator = None

        if limit is not None:
            self.limit = limit
        if next_cursor is not None:
            self.next_cursor = next_cursor
        if total_count is not None:
            self.total_count = total_count
        if part_measurement_templates is not None:
            self.part_measurement_templates = part_measurement_templates

    @property
    def limit(self):
        """Gets the limit of this PartMeasurementTemplateResponse.  # noqa: E501


        :return: The limit of this PartMeasurementTemplateResponse.  # noqa: E501
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this PartMeasurementTemplateResponse.


        :param limit: The limit of this PartMeasurementTemplateResponse.  # noqa: E501
        :type: int
        """

        self._limit = limit

    @property
    def next_cursor(self):
        """Gets the next_cursor of this PartMeasurementTemplateResponse.  # noqa: E501

        The cursor to you should use to retrieve the next set of results  # noqa: E501

        :return: The next_cursor of this PartMeasurementTemplateResponse.  # noqa: E501
        :rtype: str
        """
        return self._next_cursor

    @next_cursor.setter
    def next_cursor(self, next_cursor):
        """Sets the next_cursor of this PartMeasurementTemplateResponse.

        The cursor to you should use to retrieve the next set of results  # noqa: E501

        :param next_cursor: The next_cursor of this PartMeasurementTemplateResponse.  # noqa: E501
        :type: str
        """

        self._next_cursor = next_cursor

    @property
    def total_count(self):
        """Gets the total_count of this PartMeasurementTemplateResponse.  # noqa: E501

        Total number of records, limited to 10,000. If more than 10,000 records exist will return 10,000  # noqa: E501

        :return: The total_count of this PartMeasurementTemplateResponse.  # noqa: E501
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this PartMeasurementTemplateResponse.

        Total number of records, limited to 10,000. If more than 10,000 records exist will return 10,000  # noqa: E501

        :param total_count: The total_count of this PartMeasurementTemplateResponse.  # noqa: E501
        :type: int
        """

        self._total_count = total_count

    @property
    def part_measurement_templates(self):
        """Gets the part_measurement_templates of this PartMeasurementTemplateResponse.  # noqa: E501


        :return: The part_measurement_templates of this PartMeasurementTemplateResponse.  # noqa: E501
        :rtype: list[PartMeasurementTemplate]
        """
        return self._part_measurement_templates

    @part_measurement_templates.setter
    def part_measurement_templates(self, part_measurement_templates):
        """Sets the part_measurement_templates of this PartMeasurementTemplateResponse.


        :param part_measurement_templates: The part_measurement_templates of this PartMeasurementTemplateResponse.  # noqa: E501
        :type: list[PartMeasurementTemplate]
        """

        self._part_measurement_templates = part_measurement_templates

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PartMeasurementTemplateResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PartMeasurementTemplateResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!   # noqa: E501

    The version of the OpenAPI document: 0.4.16
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import carbon3d
from carbon3d.models.model_resolve_upload_request import ModelResolveUploadRequest  # noqa: E501
from carbon3d.rest import ApiException

class TestModelResolveUploadRequest(unittest.TestCase):
    """ModelResolveUploadRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ModelResolveUploadRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = carbon3d.models.model_resolve_upload_request.ModelResolveUploadRequest()  # noqa: E501
        if include_optional :
            return ModelResolveUploadRequest(
                filename = '/foo/bar.stl', 
                model_etag = '0d91598cfea8838a728590bd7d6a353d', 
                model_uuid = 'aaaaaaaa-f340-4da2-8784-bddd4065e75c', 
                external_id = '3ec320f4-f248-11ed-a05b-0242ac120003'
            )
        else :
            return ModelResolveUploadRequest(
                filename = '/foo/bar.stl',
                model_etag = '0d91598cfea8838a728590bd7d6a353d',
                model_uuid = 'aaaaaaaa-f340-4da2-8784-bddd4065e75c',
        )

    def testModelResolveUploadRequest(self):
        """Test ModelResolveUploadRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!   # noqa: E501

    The version of the OpenAPI document: 0.4.16
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import carbon3d
from carbon3d.models.printer import Printer  # noqa: E501
from carbon3d.rest import ApiException

class TestPrinter(unittest.TestCase):
    """Printer unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Printer
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = carbon3d.models.printer.Printer()  # noqa: E501
        if include_optional :
            return Printer(
                name = '0', 
                alias = '0', 
                serial = '0', 
                hw_type = '0', 
                url = '0', 
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                status = carbon3d.models.printer_status.Printer_status(
                    alerts = [
                        '0'
                        ], 
                    printer_state = '0', 
                    software_version = '0', ), 
                prints = carbon3d.models.printer_prints.Printer_prints(
                    last = carbon3d.models.print_ref.PrintRef(
                        name = '0', 
                        print_id = '0', 
                        build_uuid = '0', 
                        finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        remaining_sec = 56, ), 
                    current = carbon3d.models.print_ref.PrintRef(
                        name = '0', 
                        print_id = '0', 
                        build_uuid = '0', 
                        finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        remaining_sec = 56, ), 
                    next = carbon3d.models.print_ref.PrintRef(
                        name = '0', 
                        print_id = '0', 
                        build_uuid = '0', 
                        finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        remaining_sec = 56, ), 
                    queue_length = 56, )
            )
        else :
            return Printer(
                name = '0',
                serial = '0',
                hw_type = '0',
                url = '0',
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                status = carbon3d.models.printer_status.Printer_status(
                    alerts = [
                        '0'
                        ], 
                    printer_state = '0', 
                    software_version = '0', ),
                prints = carbon3d.models.printer_prints.Printer_prints(
                    last = carbon3d.models.print_ref.PrintRef(
                        name = '0', 
                        print_id = '0', 
                        build_uuid = '0', 
                        finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        remaining_sec = 56, ), 
                    current = carbon3d.models.print_ref.PrintRef(
                        name = '0', 
                        print_id = '0', 
                        build_uuid = '0', 
                        finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        remaining_sec = 56, ), 
                    next = carbon3d.models.print_ref.PrintRef(
                        name = '0', 
                        print_id = '0', 
                        build_uuid = '0', 
                        finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        remaining_sec = 56, ), 
                    queue_length = 56, ),
        )

    def testPrinter(self):
        """Test Printer"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!   # noqa: E501

    The version of the OpenAPI document: 0.4.16
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from carbon3d.configuration import Configuration


class PrintConfig(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'resin_name': 'str',
        'print_profile': 'str',
        'release_film_nm': 'int',
        'slice_thickness_nm': 'int'
    }

    attribute_map = {
        'resin_name': 'resin_name',
        'print_profile': 'print_profile',
        'release_film_nm': 'release_film_nm',
        'slice_thickness_nm': 'slice_thickness_nm'
    }

    def __init__(self, resin_name=None, print_profile=None, release_film_nm=None, slice_thickness_nm=None, local_vars_configuration=None):  # noqa: E501
        """PrintConfig - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._resin_name = None
        self._print_profile = None
        self._release_film_nm = None
        self._slice_thickness_nm = None
        self.discriminator = None

        if resin_name is not None:
            self.resin_name = resin_name
        if print_profile is not None:
            self.print_profile = print_profile
        if release_film_nm is not None:
            self.release_film_nm = release_film_nm
        if slice_thickness_nm is not None:
            self.slice_thickness_nm = slice_thickness_nm

    @property
    def resin_name(self):
        """Gets the resin_name of this PrintConfig.  # noqa: E501


        :return: The resin_name of this PrintConfig.  # noqa: E501
        :rtype: str
        """
        return self._resin_name

    @resin_name.setter
    def resin_name(self, resin_name):
        """Sets the resin_name of this PrintConfig.


        :param resin_name: The resin_name of this PrintConfig.  # noqa: E501
        :type: str
        """

        self._resin_name = resin_name

    @property
    def print_profile(self):
        """Gets the print_profile of this PrintConfig.  # noqa: E501


        :return: The print_profile of this PrintConfig.  # noqa: E501
        :rtype: str
        """
        return self._print_profile

    @print_profile.setter
    def print_profile(self, print_profile):
        """Sets the print_profile of this PrintConfig.


        :param print_profile: The print_profile of this PrintConfig.  # noqa: E501
        :type: str
        """

        self._print_profile = print_profile

    @property
    def release_film_nm(self):
        """Gets the release_film_nm of this PrintConfig.  # noqa: E501


        :return: The release_film_nm of this PrintConfig.  # noqa: E501
        :rtype: int
        """
        return self._release_film_nm

    @release_film_nm.setter
    def release_film_nm(self, release_film_nm):
        """Sets the release_film_nm of this PrintConfig.


        :param release_film_nm: The release_film_nm of this PrintConfig.  # noqa: E501
        :type: int
        """

        self._release_film_nm = release_film_nm

    @property
    def slice_thickness_nm(self):
        """Gets the slice_thickness_nm of this PrintConfig.  # noqa: E501


        :return: The slice_thickness_nm of this PrintConfig.  # noqa: E501
        :rtype: int
        """
        return self._slice_thickness_nm

    @slice_thickness_nm.setter
    def slice_thickness_nm(self, slice_thickness_nm):
        """Sets the slice_thickness_nm of this PrintConfig.


        :param slice_thickness_nm: The slice_thickness_nm of this PrintConfig.  # noqa: E501
        :type: int
        """

        self._slice_thickness_nm = slice_thickness_nm

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PrintConfig):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PrintConfig):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!   # noqa: E501

    The version of the OpenAPI document: 0.4.16
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import carbon3d
from carbon3d.api.model_program_runs_api import ModelProgramRunsApi  # noqa: E501
from carbon3d.rest import ApiException


class TestModelProgramRunsApi(unittest.TestCase):
    """ModelProgramRunsApi unit test stubs"""

    def setUp(self):
        self.api = carbon3d.api.model_program_runs_api.ModelProgramRunsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_model_program_run(self):
        """Test case for create_model_program_run

        Run a model program to alter your models  # noqa: E501
        """
        pass

    def test_create_model_program_run_typed_params(self):
        """Test case for create_model_program_run_typed_params

        Run a model program to alter your models with typed params  # noqa: E501
        """
        pass

    def test_get_model_program_run(self):
        """Test case for get_model_program_run

        Get a model program run by UUID  # noqa: E501
        """
        pass

    def test_get_model_program_runs(self):
        """Test case for get_model_program_runs

        Get a list of model program runs based on their uuids  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!   # noqa: E501

    The version of the OpenAPI document: 0.4.16
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from carbon3d.api_client import ApiClient
from carbon3d.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class ModelsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def download_model(self, uuid, **kwargs):  # noqa: E501
        """Download a model by UUID  # noqa: E501

        Download a model by UUID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_model(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str uuid: Model UUID (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.download_model_with_http_info(uuid, **kwargs)  # noqa: E501

    def download_model_with_http_info(self, uuid, **kwargs):  # noqa: E501
        """Download a model by UUID  # noqa: E501

        Download a model by UUID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_model_with_http_info(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str uuid: Model UUID (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(file, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'uuid'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method download_model" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'uuid' is set
        if self.api_client.client_side_validation and ('uuid' not in local_var_params or  # noqa: E501
                                                        local_var_params['uuid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `uuid` when calling `download_model`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uuid' in local_var_params:
            path_params['uuid'] = local_var_params['uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/models/{uuid}/download', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='file',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_models(self, **kwargs):  # noqa: E501
        """Fetch models  # noqa: E501

        Fetch Models using the given list of uuids and external_ids. At least one input array out of uuids and external_ids must be provided and the result is the union of all matching models found using given arrays.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_models(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] uuid: An array of UUIDs
        :param list[str] external_id: An array of external ids
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ModelsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.find_models_with_http_info(**kwargs)  # noqa: E501

    def find_models_with_http_info(self, **kwargs):  # noqa: E501
        """Fetch models  # noqa: E501

        Fetch Models using the given list of uuids and external_ids. At least one input array out of uuids and external_ids must be provided and the result is the union of all matching models found using given arrays.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_models_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] uuid: An array of UUIDs
        :param list[str] external_id: An array of external ids
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ModelsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'uuid',
            'external_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_models" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and ('uuid' in local_var_params and  # noqa: E501
                                                        len(local_var_params['uuid']) > 100):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `uuid` when calling `find_models`, number of items must be less than or equal to `100`")  # noqa: E501
        if self.api_client.client_side_validation and ('uuid' in local_var_params and  # noqa: E501
                                                        len(local_var_params['uuid']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `uuid` when calling `find_models`, number of items must be greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('external_id' in local_var_params and  # noqa: E501
                                                        len(local_var_params['external_id']) > 100):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `external_id` when calling `find_models`, number of items must be less than or equal to `100`")  # noqa: E501
        if self.api_client.client_side_validation and ('external_id' in local_var_params and  # noqa: E501
                                                        len(local_var_params['external_id']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `external_id` when calling `find_models`, number of items must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'uuid' in local_var_params and local_var_params['uuid'] is not None:  # noqa: E501
            query_params.append(('uuid', local_var_params['uuid']))  # noqa: E501
            collection_formats['uuid'] = 'multi'  # noqa: E501
        if 'external_id' in local_var_params and local_var_params['external_id'] is not None:  # noqa: E501
            query_params.append(('external_id', local_var_params['external_id']))  # noqa: E501
            collection_formats['external_id'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/models', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ModelsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_model(self, uuid, **kwargs):  # noqa: E501
        """Get a model by UUID  # noqa: E501

        Fetch a model by UUID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_model(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str uuid: Model UUID (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Model
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_model_with_http_info(uuid, **kwargs)  # noqa: E501

    def get_model_with_http_info(self, uuid, **kwargs):  # noqa: E501
        """Get a model by UUID  # noqa: E501

        Fetch a model by UUID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_model_with_http_info(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str uuid: Model UUID (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Model, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'uuid'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_model" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'uuid' is set
        if self.api_client.client_side_validation and ('uuid' not in local_var_params or  # noqa: E501
                                                        local_var_params['uuid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `uuid` when calling `get_model`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uuid' in local_var_params:
            path_params['uuid'] = local_var_params['uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/models/{uuid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Model',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_presigned_upload_url(self, **kwargs):  # noqa: E501
        """Create presigned upload URL for a filename  # noqa: E501

        Create presigned upload URL for a filename  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_presigned_upload_url(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ModelPresignedUploadUrlRequest model_presigned_upload_url_request: Create presigned upload URL for a filename.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ModelPresignedUploadUrlResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_presigned_upload_url_with_http_info(**kwargs)  # noqa: E501

    def get_presigned_upload_url_with_http_info(self, **kwargs):  # noqa: E501
        """Create presigned upload URL for a filename  # noqa: E501

        Create presigned upload URL for a filename  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_presigned_upload_url_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ModelPresignedUploadUrlRequest model_presigned_upload_url_request: Create presigned upload URL for a filename.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ModelPresignedUploadUrlResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'model_presigned_upload_url_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_presigned_upload_url" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'model_presigned_upload_url_request' in local_var_params:
            body_params = local_var_params['model_presigned_upload_url_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/models/presigned', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ModelPresignedUploadUrlResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def resolve_presigned_model_upload(self, **kwargs):  # noqa: E501
        """Resolve presigned model upload  # noqa: E501

        Resolve presigned model upload  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resolve_presigned_model_upload(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ModelResolveUploadRequest model_resolve_upload_request: Resolve presigned model upload
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.resolve_presigned_model_upload_with_http_info(**kwargs)  # noqa: E501

    def resolve_presigned_model_upload_with_http_info(self, **kwargs):  # noqa: E501
        """Resolve presigned model upload  # noqa: E501

        Resolve presigned model upload  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resolve_presigned_model_upload_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ModelResolveUploadRequest model_resolve_upload_request: Resolve presigned model upload
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'model_resolve_upload_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method resolve_presigned_model_upload" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'model_resolve_upload_request' in local_var_params:
            body_params = local_var_params['model_resolve_upload_request']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/models/presigned/resolve', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def upload_model(self, filename, **kwargs):  # noqa: E501
        """Upload a model  # noqa: E501

        Upload a new model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_model(filename, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str filename: Filename of the model - assumes .stl if no extension is given (required)
        :param str application_uuid: Application UUID
        :param str external_id: User provided external id
        :param file body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Model
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.upload_model_with_http_info(filename, **kwargs)  # noqa: E501

    def upload_model_with_http_info(self, filename, **kwargs):  # noqa: E501
        """Upload a model  # noqa: E501

        Upload a new model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_model_with_http_info(filename, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str filename: Filename of the model - assumes .stl if no extension is given (required)
        :param str application_uuid: Application UUID
        :param str external_id: User provided external id
        :param file body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Model, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'filename',
            'application_uuid',
            'external_id',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_model" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'filename' is set
        if self.api_client.client_side_validation and ('filename' not in local_var_params or  # noqa: E501
                                                        local_var_params['filename'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `filename` when calling `upload_model`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'filename' in local_var_params:
            header_params['filename'] = local_var_params['filename']  # noqa: E501
        if 'application_uuid' in local_var_params:
            header_params['application-uuid'] = local_var_params['application_uuid']  # noqa: E501
        if 'external_id' in local_var_params:
            header_params['external-id'] = local_var_params['external_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/octet-stream'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/models', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Model',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!   # noqa: E501

    The version of the OpenAPI document: 0.4.16
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import carbon3d
from carbon3d.models.print_data_qa import PrintDataQa  # noqa: E501
from carbon3d.rest import ApiException

class TestPrintDataQa(unittest.TestCase):
    """PrintDataQa unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PrintDataQa
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = carbon3d.models.print_data_qa.PrintDataQa()  # noqa: E501
        if include_optional :
            return PrintDataQa(
                print_id = '0', 
                printer_id = '0', 
                total_slices = '0', 
                cassette_name = '0', 
                estimated_print_time__ms = '0', 
                resin_exposure_compensation = '0', 
                base_exposure_multiplier = '0', 
                heater_setpoint__c = '0', 
                printer_serial = '0', 
                project_id = '0', 
                print_number = '0', 
                software_version = '0', 
                printer_name = '0', 
                ffb_enabled_print = '0', 
                hardware_profile = '0', 
                cassette_serial = '0', 
                window_serial = '0', 
                platform_serial = '0', 
                resin_name = '0', 
                blackline__um = '0', 
                estimated_consumed_resin_volume__ml = '0', 
                minimum_required_resin_volume__ml = '0', 
                script_name = '0', 
                project_name = '0', 
                print_finished_status = '0', 
                print_alerts = '0', 
                started_date_time = '0', 
                finished_date_time = '0', 
                total_time__min = '0', 
                move_time__min = '0', 
                exposure_time_total__min = '0', 
                total_delay_time__min = '0', 
                light_engine_intensity__m_w_cm2 = '0', 
                current_to_light_engine__m_a = '0', 
                avg_o2_partial_pressure_at_window__ = '0', 
                avg_o2_concentration__ = '0', 
                avg_o2_flow__ml_min = '0', 
                estimated_resin_volume__ml = '0', 
                slice_thickness__um = '0', 
                build_height__mm = '0', 
                created_at = '0', 
                peak_wavelength__nm = '0', 
                resin_alpha = '0', 
                resin_dc = '0', 
                resin_fc = '0', 
                resin_viscosity = '0', 
                light_engine_turned_on = '0'
            )
        else :
            return PrintDataQa(
        )

    def testPrintDataQa(self):
        """Test PrintDataQa"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!   # noqa: E501

    The version of the OpenAPI document: 0.4.16
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from carbon3d.configuration import Configuration


class ModelProgramRun(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'status': 'str',
        'progress': 'float',
        'model_uuid': 'str',
        'failure_message': 'str',
        'uuid': 'str',
        'operation_status': 'list[ModelProgramOperation]'
    }

    attribute_map = {
        'status': 'status',
        'progress': 'progress',
        'model_uuid': 'model_uuid',
        'failure_message': 'failure_message',
        'uuid': 'uuid',
        'operation_status': 'operation_status'
    }

    def __init__(self, status=None, progress=None, model_uuid=None, failure_message=None, uuid=None, operation_status=None, local_vars_configuration=None):  # noqa: E501
        """ModelProgramRun - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._status = None
        self._progress = None
        self._model_uuid = None
        self._failure_message = None
        self._uuid = None
        self._operation_status = None
        self.discriminator = None

        self.status = status
        self.progress = progress
        self.model_uuid = model_uuid
        self.failure_message = failure_message
        if uuid is not None:
            self.uuid = uuid
        self.operation_status = operation_status

    @property
    def status(self):
        """Gets the status of this ModelProgramRun.  # noqa: E501

        status of the current operation  # noqa: E501

        :return: The status of this ModelProgramRun.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ModelProgramRun.

        status of the current operation  # noqa: E501

        :param status: The status of this ModelProgramRun.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["complete", "failed", "preparing", "pending"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def progress(self):
        """Gets the progress of this ModelProgramRun.  # noqa: E501

        current progress of the concerned operation as a number between 0 and 1  # noqa: E501

        :return: The progress of this ModelProgramRun.  # noqa: E501
        :rtype: float
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """Sets the progress of this ModelProgramRun.

        current progress of the concerned operation as a number between 0 and 1  # noqa: E501

        :param progress: The progress of this ModelProgramRun.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and progress is None:  # noqa: E501
            raise ValueError("Invalid value for `progress`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                progress is not None and progress > 1):  # noqa: E501
            raise ValueError("Invalid value for `progress`, must be a value less than or equal to `1`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                progress is not None and progress < 0):  # noqa: E501
            raise ValueError("Invalid value for `progress`, must be a value greater than or equal to `0`")  # noqa: E501

        self._progress = progress

    @property
    def model_uuid(self):
        """Gets the model_uuid of this ModelProgramRun.  # noqa: E501

        uuid of the output model  # noqa: E501

        :return: The model_uuid of this ModelProgramRun.  # noqa: E501
        :rtype: str
        """
        return self._model_uuid

    @model_uuid.setter
    def model_uuid(self, model_uuid):
        """Sets the model_uuid of this ModelProgramRun.

        uuid of the output model  # noqa: E501

        :param model_uuid: The model_uuid of this ModelProgramRun.  # noqa: E501
        :type: str
        """

        self._model_uuid = model_uuid

    @property
    def failure_message(self):
        """Gets the failure_message of this ModelProgramRun.  # noqa: E501

        message in case of failure  # noqa: E501

        :return: The failure_message of this ModelProgramRun.  # noqa: E501
        :rtype: str
        """
        return self._failure_message

    @failure_message.setter
    def failure_message(self, failure_message):
        """Sets the failure_message of this ModelProgramRun.

        message in case of failure  # noqa: E501

        :param failure_message: The failure_message of this ModelProgramRun.  # noqa: E501
        :type: str
        """

        self._failure_message = failure_message

    @property
    def uuid(self):
        """Gets the uuid of this ModelProgramRun.  # noqa: E501

        uuid of the model program run  # noqa: E501

        :return: The uuid of this ModelProgramRun.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this ModelProgramRun.

        uuid of the model program run  # noqa: E501

        :param uuid: The uuid of this ModelProgramRun.  # noqa: E501
        :type: str
        """

        self._uuid = uuid

    @property
    def operation_status(self):
        """Gets the operation_status of this ModelProgramRun.  # noqa: E501

        details about the statuses and outputs of named operations specified by the customer  # noqa: E501

        :return: The operation_status of this ModelProgramRun.  # noqa: E501
        :rtype: list[ModelProgramOperation]
        """
        return self._operation_status

    @operation_status.setter
    def operation_status(self, operation_status):
        """Sets the operation_status of this ModelProgramRun.

        details about the statuses and outputs of named operations specified by the customer  # noqa: E501

        :param operation_status: The operation_status of this ModelProgramRun.  # noqa: E501
        :type: list[ModelProgramOperation]
        """

        self._operation_status = operation_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelProgramRun):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModelProgramRun):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!   # noqa: E501

    The version of the OpenAPI document: 0.4.16
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import carbon3d
from carbon3d.models.part_measurement_response import PartMeasurementResponse  # noqa: E501
from carbon3d.rest import ApiException

class TestPartMeasurementResponse(unittest.TestCase):
    """PartMeasurementResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PartMeasurementResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = carbon3d.models.part_measurement_response.PartMeasurementResponse()  # noqa: E501
        if include_optional :
            return PartMeasurementResponse(
                limit = 56, 
                next_cursor = 'dXNlcjpXMDdRQ1JQQTQ=', 
                total_count = 56, 
                part_measurements = [
                    {"uuid":"c13fcaeb-b106-4126-9ca6-3ecbb0ba3124","printed_part_uuid":"75e4811b-0f54-4ce0-a93a-511668b08b49","part_measurement_template_uuid":"261bfc3a-1644-4b78-80be-264d3c85dc15","value":null,"category_value":"adhesion","zones":["A","B"],"measurement_result":"fail","notes":"Some notes","updated_at":"2020-03-28T12:25:00.000Z"}
                    ]
            )
        else :
            return PartMeasurementResponse(
        )

    def testPartMeasurementResponse(self):
        """Test PartMeasurementResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!   # noqa: E501

    The version of the OpenAPI document: 0.4.16
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import carbon3d
from carbon3d.models.printed_part import PrintedPart  # noqa: E501
from carbon3d.rest import ApiException

class TestPrintedPart(unittest.TestCase):
    """PrintedPart unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PrintedPart
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = carbon3d.models.printed_part.PrintedPart()  # noqa: E501
        if include_optional :
            return PrintedPart(
                uuid = '0', 
                part_uuid = '0', 
                model_uuid = '0', 
                part_number = '0', 
                build_uuid = '0', 
                part_order_uuid = '0', 
                part_order_number = '0', 
                print_order_uuid = '0', 
                print_order_number = '0', 
                print_id = '0', 
                project_blackline = 1.337, 
                resin_cell_name = '0', 
                resin_lot_number = '0', 
                print_uuid = '0', 
                serial_number = '0', 
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                tags = carbon3d.models.printed_part_tags.PrintedPart_tags(
                    part_number = {
                        'key' : '0'
                        }, 
                    part = {
                        'key' : '0'
                        }, 
                    printed_part = {
                        'key' : '0'
                        }, ), 
                status = 'waiting', 
                error = '0'
            )
        else :
            return PrintedPart(
                uuid = '0',
                part_uuid = '0',
                status = 'waiting',
        )

    def testPrintedPart(self):
        """Test PrintedPart"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!   # noqa: E501

    The version of the OpenAPI document: 0.4.16
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import carbon3d
from carbon3d.models.model import Model  # noqa: E501
from carbon3d.rest import ApiException

class TestModel(unittest.TestCase):
    """Model unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Model
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = carbon3d.models.model.Model()  # noqa: E501
        if include_optional :
            return Model(
                uuid = '1cf34076-417e-489f-8863-3438facd4808', 
                filename = 'file.stl', 
                external_id = '3ec320f4-f248-11ed-a05b-0242ac120003', 
                application_uuid = '6401c93f-f340-4da2-8784-bddd4065e75c', 
                description = 'Sample model description', 
                file_size_bytes = 1024, 
                updated_at = '2017-07-21T17:32:28Z', 
                created_at = '2017-07-21T17:32:28Z', 
                created_by = 'John Doe'
            )
        else :
            return Model(
                uuid = '1cf34076-417e-489f-8863-3438facd4808',
                filename = 'file.stl',
        )

    def testModel(self):
        """Test Model"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!   # noqa: E501

    The version of the OpenAPI document: 0.4.16
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from carbon3d.configuration import Configuration


class PrintDataQa(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'print_id': 'str',
        'printer_id': 'str',
        'total_slices': 'str',
        'cassette_name': 'str',
        'estimated_print_time__ms': 'str',
        'resin_exposure_compensation': 'str',
        'base_exposure_multiplier': 'str',
        'heater_setpoint__c': 'str',
        'printer_serial': 'str',
        'project_id': 'str',
        'print_number': 'str',
        'software_version': 'str',
        'printer_name': 'str',
        'ffb_enabled_print': 'str',
        'hardware_profile': 'str',
        'cassette_serial': 'str',
        'window_serial': 'str',
        'platform_serial': 'str',
        'resin_name': 'str',
        'blackline__um': 'str',
        'estimated_consumed_resin_volume__ml': 'str',
        'minimum_required_resin_volume__ml': 'str',
        'script_name': 'str',
        'project_name': 'str',
        'print_finished_status': 'str',
        'print_alerts': 'str',
        'started_date_time': 'str',
        'finished_date_time': 'str',
        'total_time__min': 'str',
        'move_time__min': 'str',
        'exposure_time_total__min': 'str',
        'total_delay_time__min': 'str',
        'light_engine_intensity__m_w_cm2': 'str',
        'current_to_light_engine__m_a': 'str',
        'avg_o2_partial_pressure_at_window__': 'str',
        'avg_o2_concentration__': 'str',
        'avg_o2_flow__ml_min': 'str',
        'estimated_resin_volume__ml': 'str',
        'slice_thickness__um': 'str',
        'build_height__mm': 'str',
        'created_at': 'str',
        'peak_wavelength__nm': 'str',
        'resin_alpha': 'str',
        'resin_dc': 'str',
        'resin_fc': 'str',
        'resin_viscosity': 'str',
        'light_engine_turned_on': 'str'
    }

    attribute_map = {
        'print_id': 'Print ID',
        'printer_id': 'Printer ID',
        'total_slices': 'Total Slices',
        'cassette_name': 'Cassette Name',
        'estimated_print_time__ms': 'Estimated Print Time (ms)',
        'resin_exposure_compensation': 'Resin Exposure Compensation',
        'base_exposure_multiplier': 'Base Exposure Multiplier',
        'heater_setpoint__c': 'Heater Setpoint (C)',
        'printer_serial': 'Printer Serial',
        'project_id': 'Project ID',
        'print_number': 'Print Number',
        'software_version': 'Software Version',
        'printer_name': 'Printer Name',
        'ffb_enabled_print': 'FFB Enabled Print',
        'hardware_profile': 'Hardware Profile',
        'cassette_serial': 'Cassette Serial',
        'window_serial': 'Window Serial',
        'platform_serial': 'Platform Serial',
        'resin_name': 'Resin Name',
        'blackline__um': 'Blackline (um)',
        'estimated_consumed_resin_volume__ml': 'Estimated Consumed Resin Volume (ml)',
        'minimum_required_resin_volume__ml': 'Minimum Required Resin Volume (ml)',
        'script_name': 'Script Name',
        'project_name': 'Project Name',
        'print_finished_status': 'Print Finished Status',
        'print_alerts': 'Print Alerts',
        'started_date_time': 'Started Date-Time',
        'finished_date_time': 'Finished Date-Time',
        'total_time__min': 'Total Time (min)',
        'move_time__min': 'Move Time (min)',
        'exposure_time_total__min': 'Exposure Time Total (min)',
        'total_delay_time__min': 'Total Delay Time (min)',
        'light_engine_intensity__m_w_cm2': 'Light Engine Intensity (mW/cm2)',
        'current_to_light_engine__m_a': 'Current to Light Engine (mA)',
        'avg_o2_partial_pressure_at_window__': 'Avg O2 Partial Pressure at Window (%)',
        'avg_o2_concentration__': 'Avg O2 Concentration (%)',
        'avg_o2_flow__ml_min': 'Avg O2 Flow (ml/min)',
        'estimated_resin_volume__ml': 'Estimated Resin Volume (ml)',
        'slice_thickness__um': 'Slice Thickness (um)',
        'build_height__mm': 'Build Height (mm)',
        'created_at': 'Created At',
        'peak_wavelength__nm': 'Peak Wavelength (nm)',
        'resin_alpha': 'Resin Alpha',
        'resin_dc': 'Resin DC',
        'resin_fc': 'Resin FC',
        'resin_viscosity': 'Resin Viscosity',
        'light_engine_turned_on': 'Light Engine Turned On'
    }

    def __init__(self, print_id=None, printer_id=None, total_slices=None, cassette_name=None, estimated_print_time__ms=None, resin_exposure_compensation=None, base_exposure_multiplier=None, heater_setpoint__c=None, printer_serial=None, project_id=None, print_number=None, software_version=None, printer_name=None, ffb_enabled_print=None, hardware_profile=None, cassette_serial=None, window_serial=None, platform_serial=None, resin_name=None, blackline__um=None, estimated_consumed_resin_volume__ml=None, minimum_required_resin_volume__ml=None, script_name=None, project_name=None, print_finished_status=None, print_alerts=None, started_date_time=None, finished_date_time=None, total_time__min=None, move_time__min=None, exposure_time_total__min=None, total_delay_time__min=None, light_engine_intensity__m_w_cm2=None, current_to_light_engine__m_a=None, avg_o2_partial_pressure_at_window__=None, avg_o2_concentration__=None, avg_o2_flow__ml_min=None, estimated_resin_volume__ml=None, slice_thickness__um=None, build_height__mm=None, created_at=None, peak_wavelength__nm=None, resin_alpha=None, resin_dc=None, resin_fc=None, resin_viscosity=None, light_engine_turned_on=None, local_vars_configuration=None):  # noqa: E501
        """PrintDataQa - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._print_id = None
        self._printer_id = None
        self._total_slices = None
        self._cassette_name = None
        self._estimated_print_time__ms = None
        self._resin_exposure_compensation = None
        self._base_exposure_multiplier = None
        self._heater_setpoint__c = None
        self._printer_serial = None
        self._project_id = None
        self._print_number = None
        self._software_version = None
        self._printer_name = None
        self._ffb_enabled_print = None
        self._hardware_profile = None
        self._cassette_serial = None
        self._window_serial = None
        self._platform_serial = None
        self._resin_name = None
        self._blackline__um = None
        self._estimated_consumed_resin_volume__ml = None
        self._minimum_required_resin_volume__ml = None
        self._script_name = None
        self._project_name = None
        self._print_finished_status = None
        self._print_alerts = None
        self._started_date_time = None
        self._finished_date_time = None
        self._total_time__min = None
        self._move_time__min = None
        self._exposure_time_total__min = None
        self._total_delay_time__min = None
        self._light_engine_intensity__m_w_cm2 = None
        self._current_to_light_engine__m_a = None
        self._avg_o2_partial_pressure_at_window__ = None
        self._avg_o2_concentration__ = None
        self._avg_o2_flow__ml_min = None
        self._estimated_resin_volume__ml = None
        self._slice_thickness__um = None
        self._build_height__mm = None
        self._created_at = None
        self._peak_wavelength__nm = None
        self._resin_alpha = None
        self._resin_dc = None
        self._resin_fc = None
        self._resin_viscosity = None
        self._light_engine_turned_on = None
        self.discriminator = None

        if print_id is not None:
            self.print_id = print_id
        if printer_id is not None:
            self.printer_id = printer_id
        if total_slices is not None:
            self.total_slices = total_slices
        if cassette_name is not None:
            self.cassette_name = cassette_name
        if estimated_print_time__ms is not None:
            self.estimated_print_time__ms = estimated_print_time__ms
        if resin_exposure_compensation is not None:
            self.resin_exposure_compensation = resin_exposure_compensation
        if base_exposure_multiplier is not None:
            self.base_exposure_multiplier = base_exposure_multiplier
        if heater_setpoint__c is not None:
            self.heater_setpoint__c = heater_setpoint__c
        if printer_serial is not None:
            self.printer_serial = printer_serial
        if project_id is not None:
            self.project_id = project_id
        if print_number is not None:
            self.print_number = print_number
        if software_version is not None:
            self.software_version = software_version
        if printer_name is not None:
            self.printer_name = printer_name
        if ffb_enabled_print is not None:
            self.ffb_enabled_print = ffb_enabled_print
        if hardware_profile is not None:
            self.hardware_profile = hardware_profile
        if cassette_serial is not None:
            self.cassette_serial = cassette_serial
        if window_serial is not None:
            self.window_serial = window_serial
        if platform_serial is not None:
            self.platform_serial = platform_serial
        if resin_name is not None:
            self.resin_name = resin_name
        if blackline__um is not None:
            self.blackline__um = blackline__um
        if estimated_consumed_resin_volume__ml is not None:
            self.estimated_consumed_resin_volume__ml = estimated_consumed_resin_volume__ml
        if minimum_required_resin_volume__ml is not None:
            self.minimum_required_resin_volume__ml = minimum_required_resin_volume__ml
        if script_name is not None:
            self.script_name = script_name
        if project_name is not None:
            self.project_name = project_name
        if print_finished_status is not None:
            self.print_finished_status = print_finished_status
        if print_alerts is not None:
            self.print_alerts = print_alerts
        if started_date_time is not None:
            self.started_date_time = started_date_time
        if finished_date_time is not None:
            self.finished_date_time = finished_date_time
        if total_time__min is not None:
            self.total_time__min = total_time__min
        if move_time__min is not None:
            self.move_time__min = move_time__min
        if exposure_time_total__min is not None:
            self.exposure_time_total__min = exposure_time_total__min
        if total_delay_time__min is not None:
            self.total_delay_time__min = total_delay_time__min
        if light_engine_intensity__m_w_cm2 is not None:
            self.light_engine_intensity__m_w_cm2 = light_engine_intensity__m_w_cm2
        if current_to_light_engine__m_a is not None:
            self.current_to_light_engine__m_a = current_to_light_engine__m_a
        if avg_o2_partial_pressure_at_window__ is not None:
            self.avg_o2_partial_pressure_at_window__ = avg_o2_partial_pressure_at_window__
        if avg_o2_concentration__ is not None:
            self.avg_o2_concentration__ = avg_o2_concentration__
        if avg_o2_flow__ml_min is not None:
            self.avg_o2_flow__ml_min = avg_o2_flow__ml_min
        if estimated_resin_volume__ml is not None:
            self.estimated_resin_volume__ml = estimated_resin_volume__ml
        if slice_thickness__um is not None:
            self.slice_thickness__um = slice_thickness__um
        if build_height__mm is not None:
            self.build_height__mm = build_height__mm
        if created_at is not None:
            self.created_at = created_at
        if peak_wavelength__nm is not None:
            self.peak_wavelength__nm = peak_wavelength__nm
        if resin_alpha is not None:
            self.resin_alpha = resin_alpha
        if resin_dc is not None:
            self.resin_dc = resin_dc
        if resin_fc is not None:
            self.resin_fc = resin_fc
        if resin_viscosity is not None:
            self.resin_viscosity = resin_viscosity
        if light_engine_turned_on is not None:
            self.light_engine_turned_on = light_engine_turned_on

    @property
    def print_id(self):
        """Gets the print_id of this PrintDataQa.  # noqa: E501


        :return: The print_id of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._print_id

    @print_id.setter
    def print_id(self, print_id):
        """Sets the print_id of this PrintDataQa.


        :param print_id: The print_id of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._print_id = print_id

    @property
    def printer_id(self):
        """Gets the printer_id of this PrintDataQa.  # noqa: E501


        :return: The printer_id of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._printer_id

    @printer_id.setter
    def printer_id(self, printer_id):
        """Sets the printer_id of this PrintDataQa.


        :param printer_id: The printer_id of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._printer_id = printer_id

    @property
    def total_slices(self):
        """Gets the total_slices of this PrintDataQa.  # noqa: E501


        :return: The total_slices of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._total_slices

    @total_slices.setter
    def total_slices(self, total_slices):
        """Sets the total_slices of this PrintDataQa.


        :param total_slices: The total_slices of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._total_slices = total_slices

    @property
    def cassette_name(self):
        """Gets the cassette_name of this PrintDataQa.  # noqa: E501


        :return: The cassette_name of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._cassette_name

    @cassette_name.setter
    def cassette_name(self, cassette_name):
        """Sets the cassette_name of this PrintDataQa.


        :param cassette_name: The cassette_name of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._cassette_name = cassette_name

    @property
    def estimated_print_time__ms(self):
        """Gets the estimated_print_time__ms of this PrintDataQa.  # noqa: E501


        :return: The estimated_print_time__ms of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._estimated_print_time__ms

    @estimated_print_time__ms.setter
    def estimated_print_time__ms(self, estimated_print_time__ms):
        """Sets the estimated_print_time__ms of this PrintDataQa.


        :param estimated_print_time__ms: The estimated_print_time__ms of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._estimated_print_time__ms = estimated_print_time__ms

    @property
    def resin_exposure_compensation(self):
        """Gets the resin_exposure_compensation of this PrintDataQa.  # noqa: E501


        :return: The resin_exposure_compensation of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._resin_exposure_compensation

    @resin_exposure_compensation.setter
    def resin_exposure_compensation(self, resin_exposure_compensation):
        """Sets the resin_exposure_compensation of this PrintDataQa.


        :param resin_exposure_compensation: The resin_exposure_compensation of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._resin_exposure_compensation = resin_exposure_compensation

    @property
    def base_exposure_multiplier(self):
        """Gets the base_exposure_multiplier of this PrintDataQa.  # noqa: E501


        :return: The base_exposure_multiplier of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._base_exposure_multiplier

    @base_exposure_multiplier.setter
    def base_exposure_multiplier(self, base_exposure_multiplier):
        """Sets the base_exposure_multiplier of this PrintDataQa.


        :param base_exposure_multiplier: The base_exposure_multiplier of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._base_exposure_multiplier = base_exposure_multiplier

    @property
    def heater_setpoint__c(self):
        """Gets the heater_setpoint__c of this PrintDataQa.  # noqa: E501


        :return: The heater_setpoint__c of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._heater_setpoint__c

    @heater_setpoint__c.setter
    def heater_setpoint__c(self, heater_setpoint__c):
        """Sets the heater_setpoint__c of this PrintDataQa.


        :param heater_setpoint__c: The heater_setpoint__c of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._heater_setpoint__c = heater_setpoint__c

    @property
    def printer_serial(self):
        """Gets the printer_serial of this PrintDataQa.  # noqa: E501


        :return: The printer_serial of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._printer_serial

    @printer_serial.setter
    def printer_serial(self, printer_serial):
        """Sets the printer_serial of this PrintDataQa.


        :param printer_serial: The printer_serial of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._printer_serial = printer_serial

    @property
    def project_id(self):
        """Gets the project_id of this PrintDataQa.  # noqa: E501


        :return: The project_id of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this PrintDataQa.


        :param project_id: The project_id of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def print_number(self):
        """Gets the print_number of this PrintDataQa.  # noqa: E501


        :return: The print_number of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._print_number

    @print_number.setter
    def print_number(self, print_number):
        """Sets the print_number of this PrintDataQa.


        :param print_number: The print_number of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._print_number = print_number

    @property
    def software_version(self):
        """Gets the software_version of this PrintDataQa.  # noqa: E501


        :return: The software_version of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._software_version

    @software_version.setter
    def software_version(self, software_version):
        """Sets the software_version of this PrintDataQa.


        :param software_version: The software_version of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._software_version = software_version

    @property
    def printer_name(self):
        """Gets the printer_name of this PrintDataQa.  # noqa: E501


        :return: The printer_name of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._printer_name

    @printer_name.setter
    def printer_name(self, printer_name):
        """Sets the printer_name of this PrintDataQa.


        :param printer_name: The printer_name of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._printer_name = printer_name

    @property
    def ffb_enabled_print(self):
        """Gets the ffb_enabled_print of this PrintDataQa.  # noqa: E501


        :return: The ffb_enabled_print of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._ffb_enabled_print

    @ffb_enabled_print.setter
    def ffb_enabled_print(self, ffb_enabled_print):
        """Sets the ffb_enabled_print of this PrintDataQa.


        :param ffb_enabled_print: The ffb_enabled_print of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._ffb_enabled_print = ffb_enabled_print

    @property
    def hardware_profile(self):
        """Gets the hardware_profile of this PrintDataQa.  # noqa: E501


        :return: The hardware_profile of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._hardware_profile

    @hardware_profile.setter
    def hardware_profile(self, hardware_profile):
        """Sets the hardware_profile of this PrintDataQa.


        :param hardware_profile: The hardware_profile of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._hardware_profile = hardware_profile

    @property
    def cassette_serial(self):
        """Gets the cassette_serial of this PrintDataQa.  # noqa: E501


        :return: The cassette_serial of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._cassette_serial

    @cassette_serial.setter
    def cassette_serial(self, cassette_serial):
        """Sets the cassette_serial of this PrintDataQa.


        :param cassette_serial: The cassette_serial of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._cassette_serial = cassette_serial

    @property
    def window_serial(self):
        """Gets the window_serial of this PrintDataQa.  # noqa: E501


        :return: The window_serial of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._window_serial

    @window_serial.setter
    def window_serial(self, window_serial):
        """Sets the window_serial of this PrintDataQa.


        :param window_serial: The window_serial of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._window_serial = window_serial

    @property
    def platform_serial(self):
        """Gets the platform_serial of this PrintDataQa.  # noqa: E501


        :return: The platform_serial of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._platform_serial

    @platform_serial.setter
    def platform_serial(self, platform_serial):
        """Sets the platform_serial of this PrintDataQa.


        :param platform_serial: The platform_serial of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._platform_serial = platform_serial

    @property
    def resin_name(self):
        """Gets the resin_name of this PrintDataQa.  # noqa: E501


        :return: The resin_name of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._resin_name

    @resin_name.setter
    def resin_name(self, resin_name):
        """Sets the resin_name of this PrintDataQa.


        :param resin_name: The resin_name of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._resin_name = resin_name

    @property
    def blackline__um(self):
        """Gets the blackline__um of this PrintDataQa.  # noqa: E501


        :return: The blackline__um of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._blackline__um

    @blackline__um.setter
    def blackline__um(self, blackline__um):
        """Sets the blackline__um of this PrintDataQa.


        :param blackline__um: The blackline__um of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._blackline__um = blackline__um

    @property
    def estimated_consumed_resin_volume__ml(self):
        """Gets the estimated_consumed_resin_volume__ml of this PrintDataQa.  # noqa: E501


        :return: The estimated_consumed_resin_volume__ml of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._estimated_consumed_resin_volume__ml

    @estimated_consumed_resin_volume__ml.setter
    def estimated_consumed_resin_volume__ml(self, estimated_consumed_resin_volume__ml):
        """Sets the estimated_consumed_resin_volume__ml of this PrintDataQa.


        :param estimated_consumed_resin_volume__ml: The estimated_consumed_resin_volume__ml of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._estimated_consumed_resin_volume__ml = estimated_consumed_resin_volume__ml

    @property
    def minimum_required_resin_volume__ml(self):
        """Gets the minimum_required_resin_volume__ml of this PrintDataQa.  # noqa: E501


        :return: The minimum_required_resin_volume__ml of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._minimum_required_resin_volume__ml

    @minimum_required_resin_volume__ml.setter
    def minimum_required_resin_volume__ml(self, minimum_required_resin_volume__ml):
        """Sets the minimum_required_resin_volume__ml of this PrintDataQa.


        :param minimum_required_resin_volume__ml: The minimum_required_resin_volume__ml of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._minimum_required_resin_volume__ml = minimum_required_resin_volume__ml

    @property
    def script_name(self):
        """Gets the script_name of this PrintDataQa.  # noqa: E501


        :return: The script_name of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._script_name

    @script_name.setter
    def script_name(self, script_name):
        """Sets the script_name of this PrintDataQa.


        :param script_name: The script_name of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._script_name = script_name

    @property
    def project_name(self):
        """Gets the project_name of this PrintDataQa.  # noqa: E501


        :return: The project_name of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this PrintDataQa.


        :param project_name: The project_name of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def print_finished_status(self):
        """Gets the print_finished_status of this PrintDataQa.  # noqa: E501


        :return: The print_finished_status of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._print_finished_status

    @print_finished_status.setter
    def print_finished_status(self, print_finished_status):
        """Sets the print_finished_status of this PrintDataQa.


        :param print_finished_status: The print_finished_status of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._print_finished_status = print_finished_status

    @property
    def print_alerts(self):
        """Gets the print_alerts of this PrintDataQa.  # noqa: E501


        :return: The print_alerts of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._print_alerts

    @print_alerts.setter
    def print_alerts(self, print_alerts):
        """Sets the print_alerts of this PrintDataQa.


        :param print_alerts: The print_alerts of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._print_alerts = print_alerts

    @property
    def started_date_time(self):
        """Gets the started_date_time of this PrintDataQa.  # noqa: E501


        :return: The started_date_time of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._started_date_time

    @started_date_time.setter
    def started_date_time(self, started_date_time):
        """Sets the started_date_time of this PrintDataQa.


        :param started_date_time: The started_date_time of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._started_date_time = started_date_time

    @property
    def finished_date_time(self):
        """Gets the finished_date_time of this PrintDataQa.  # noqa: E501


        :return: The finished_date_time of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._finished_date_time

    @finished_date_time.setter
    def finished_date_time(self, finished_date_time):
        """Sets the finished_date_time of this PrintDataQa.


        :param finished_date_time: The finished_date_time of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._finished_date_time = finished_date_time

    @property
    def total_time__min(self):
        """Gets the total_time__min of this PrintDataQa.  # noqa: E501


        :return: The total_time__min of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._total_time__min

    @total_time__min.setter
    def total_time__min(self, total_time__min):
        """Sets the total_time__min of this PrintDataQa.


        :param total_time__min: The total_time__min of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._total_time__min = total_time__min

    @property
    def move_time__min(self):
        """Gets the move_time__min of this PrintDataQa.  # noqa: E501


        :return: The move_time__min of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._move_time__min

    @move_time__min.setter
    def move_time__min(self, move_time__min):
        """Sets the move_time__min of this PrintDataQa.


        :param move_time__min: The move_time__min of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._move_time__min = move_time__min

    @property
    def exposure_time_total__min(self):
        """Gets the exposure_time_total__min of this PrintDataQa.  # noqa: E501


        :return: The exposure_time_total__min of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._exposure_time_total__min

    @exposure_time_total__min.setter
    def exposure_time_total__min(self, exposure_time_total__min):
        """Sets the exposure_time_total__min of this PrintDataQa.


        :param exposure_time_total__min: The exposure_time_total__min of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._exposure_time_total__min = exposure_time_total__min

    @property
    def total_delay_time__min(self):
        """Gets the total_delay_time__min of this PrintDataQa.  # noqa: E501


        :return: The total_delay_time__min of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._total_delay_time__min

    @total_delay_time__min.setter
    def total_delay_time__min(self, total_delay_time__min):
        """Sets the total_delay_time__min of this PrintDataQa.


        :param total_delay_time__min: The total_delay_time__min of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._total_delay_time__min = total_delay_time__min

    @property
    def light_engine_intensity__m_w_cm2(self):
        """Gets the light_engine_intensity__m_w_cm2 of this PrintDataQa.  # noqa: E501


        :return: The light_engine_intensity__m_w_cm2 of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._light_engine_intensity__m_w_cm2

    @light_engine_intensity__m_w_cm2.setter
    def light_engine_intensity__m_w_cm2(self, light_engine_intensity__m_w_cm2):
        """Sets the light_engine_intensity__m_w_cm2 of this PrintDataQa.


        :param light_engine_intensity__m_w_cm2: The light_engine_intensity__m_w_cm2 of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._light_engine_intensity__m_w_cm2 = light_engine_intensity__m_w_cm2

    @property
    def current_to_light_engine__m_a(self):
        """Gets the current_to_light_engine__m_a of this PrintDataQa.  # noqa: E501


        :return: The current_to_light_engine__m_a of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._current_to_light_engine__m_a

    @current_to_light_engine__m_a.setter
    def current_to_light_engine__m_a(self, current_to_light_engine__m_a):
        """Sets the current_to_light_engine__m_a of this PrintDataQa.


        :param current_to_light_engine__m_a: The current_to_light_engine__m_a of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._current_to_light_engine__m_a = current_to_light_engine__m_a

    @property
    def avg_o2_partial_pressure_at_window__(self):
        """Gets the avg_o2_partial_pressure_at_window__ of this PrintDataQa.  # noqa: E501


        :return: The avg_o2_partial_pressure_at_window__ of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._avg_o2_partial_pressure_at_window__

    @avg_o2_partial_pressure_at_window__.setter
    def avg_o2_partial_pressure_at_window__(self, avg_o2_partial_pressure_at_window__):
        """Sets the avg_o2_partial_pressure_at_window__ of this PrintDataQa.


        :param avg_o2_partial_pressure_at_window__: The avg_o2_partial_pressure_at_window__ of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._avg_o2_partial_pressure_at_window__ = avg_o2_partial_pressure_at_window__

    @property
    def avg_o2_concentration__(self):
        """Gets the avg_o2_concentration__ of this PrintDataQa.  # noqa: E501


        :return: The avg_o2_concentration__ of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._avg_o2_concentration__

    @avg_o2_concentration__.setter
    def avg_o2_concentration__(self, avg_o2_concentration__):
        """Sets the avg_o2_concentration__ of this PrintDataQa.


        :param avg_o2_concentration__: The avg_o2_concentration__ of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._avg_o2_concentration__ = avg_o2_concentration__

    @property
    def avg_o2_flow__ml_min(self):
        """Gets the avg_o2_flow__ml_min of this PrintDataQa.  # noqa: E501


        :return: The avg_o2_flow__ml_min of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._avg_o2_flow__ml_min

    @avg_o2_flow__ml_min.setter
    def avg_o2_flow__ml_min(self, avg_o2_flow__ml_min):
        """Sets the avg_o2_flow__ml_min of this PrintDataQa.


        :param avg_o2_flow__ml_min: The avg_o2_flow__ml_min of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._avg_o2_flow__ml_min = avg_o2_flow__ml_min

    @property
    def estimated_resin_volume__ml(self):
        """Gets the estimated_resin_volume__ml of this PrintDataQa.  # noqa: E501


        :return: The estimated_resin_volume__ml of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._estimated_resin_volume__ml

    @estimated_resin_volume__ml.setter
    def estimated_resin_volume__ml(self, estimated_resin_volume__ml):
        """Sets the estimated_resin_volume__ml of this PrintDataQa.


        :param estimated_resin_volume__ml: The estimated_resin_volume__ml of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._estimated_resin_volume__ml = estimated_resin_volume__ml

    @property
    def slice_thickness__um(self):
        """Gets the slice_thickness__um of this PrintDataQa.  # noqa: E501


        :return: The slice_thickness__um of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._slice_thickness__um

    @slice_thickness__um.setter
    def slice_thickness__um(self, slice_thickness__um):
        """Sets the slice_thickness__um of this PrintDataQa.


        :param slice_thickness__um: The slice_thickness__um of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._slice_thickness__um = slice_thickness__um

    @property
    def build_height__mm(self):
        """Gets the build_height__mm of this PrintDataQa.  # noqa: E501


        :return: The build_height__mm of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._build_height__mm

    @build_height__mm.setter
    def build_height__mm(self, build_height__mm):
        """Sets the build_height__mm of this PrintDataQa.


        :param build_height__mm: The build_height__mm of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._build_height__mm = build_height__mm

    @property
    def created_at(self):
        """Gets the created_at of this PrintDataQa.  # noqa: E501


        :return: The created_at of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PrintDataQa.


        :param created_at: The created_at of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def peak_wavelength__nm(self):
        """Gets the peak_wavelength__nm of this PrintDataQa.  # noqa: E501


        :return: The peak_wavelength__nm of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._peak_wavelength__nm

    @peak_wavelength__nm.setter
    def peak_wavelength__nm(self, peak_wavelength__nm):
        """Sets the peak_wavelength__nm of this PrintDataQa.


        :param peak_wavelength__nm: The peak_wavelength__nm of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._peak_wavelength__nm = peak_wavelength__nm

    @property
    def resin_alpha(self):
        """Gets the resin_alpha of this PrintDataQa.  # noqa: E501


        :return: The resin_alpha of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._resin_alpha

    @resin_alpha.setter
    def resin_alpha(self, resin_alpha):
        """Sets the resin_alpha of this PrintDataQa.


        :param resin_alpha: The resin_alpha of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._resin_alpha = resin_alpha

    @property
    def resin_dc(self):
        """Gets the resin_dc of this PrintDataQa.  # noqa: E501


        :return: The resin_dc of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._resin_dc

    @resin_dc.setter
    def resin_dc(self, resin_dc):
        """Sets the resin_dc of this PrintDataQa.


        :param resin_dc: The resin_dc of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._resin_dc = resin_dc

    @property
    def resin_fc(self):
        """Gets the resin_fc of this PrintDataQa.  # noqa: E501


        :return: The resin_fc of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._resin_fc

    @resin_fc.setter
    def resin_fc(self, resin_fc):
        """Sets the resin_fc of this PrintDataQa.


        :param resin_fc: The resin_fc of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._resin_fc = resin_fc

    @property
    def resin_viscosity(self):
        """Gets the resin_viscosity of this PrintDataQa.  # noqa: E501


        :return: The resin_viscosity of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._resin_viscosity

    @resin_viscosity.setter
    def resin_viscosity(self, resin_viscosity):
        """Sets the resin_viscosity of this PrintDataQa.


        :param resin_viscosity: The resin_viscosity of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._resin_viscosity = resin_viscosity

    @property
    def light_engine_turned_on(self):
        """Gets the light_engine_turned_on of this PrintDataQa.  # noqa: E501


        :return: The light_engine_turned_on of this PrintDataQa.  # noqa: E501
        :rtype: str
        """
        return self._light_engine_turned_on

    @light_engine_turned_on.setter
    def light_engine_turned_on(self, light_engine_turned_on):
        """Sets the light_engine_turned_on of this PrintDataQa.


        :param light_engine_turned_on: The light_engine_turned_on of this PrintDataQa.  # noqa: E501
        :type: str
        """

        self._light_engine_turned_on = light_engine_turned_on

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PrintDataQa):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PrintDataQa):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!   # noqa: E501

    The version of the OpenAPI document: 0.4.16
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import carbon3d
from carbon3d.models.print_order import PrintOrder  # noqa: E501
from carbon3d.rest import ApiException

class TestPrintOrder(unittest.TestCase):
    """PrintOrder unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PrintOrder
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = carbon3d.models.print_order.PrintOrder()  # noqa: E501
        if include_optional :
            return PrintOrder(
                uuid = '0', 
                build_uuid = '0', 
                total_copies = 56, 
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                print_order_number = '0', 
                print_order_tags = {
                    'key' : '0'
                    }, 
                notes = '0', 
                routed_to = {
                    'key' : carbon3d.models.print_order_routed_to.PrintOrder_routed_to(
                        copies_queued = 56, 
                        copies_printed = 56, )
                    }
            )
        else :
            return PrintOrder(
        )

    def testPrintOrder(self):
        """Test PrintOrder"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!   # noqa: E501

    The version of the OpenAPI document: 0.4.16
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "carbon3d-client"
VERSION = "0.4.16"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Carbon DLS API",
    author="Carbon API Support",
    author_email="api-list@carbon3d.com",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "Carbon DLS API"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description="""\
    Welcome to the Carbon DLS API docs!   # noqa: E501
    """
)



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!   # noqa: E501

    The version of the OpenAPI document: 0.4.16
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from carbon3d.configuration import Configuration


class PrintOrigin(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cassette_serial': 'str',
        'cassette_nfc_uid': 'str',
        'platform_serial': 'str',
        'platform_nfc_uid': 'str',
        'printer_serial': 'str',
        'software_version': 'str'
    }

    attribute_map = {
        'cassette_serial': 'cassette_serial',
        'cassette_nfc_uid': 'cassette_nfc_uid',
        'platform_serial': 'platform_serial',
        'platform_nfc_uid': 'platform_nfc_uid',
        'printer_serial': 'printer_serial',
        'software_version': 'software_version'
    }

    def __init__(self, cassette_serial=None, cassette_nfc_uid=None, platform_serial=None, platform_nfc_uid=None, printer_serial=None, software_version=None, local_vars_configuration=None):  # noqa: E501
        """PrintOrigin - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._cassette_serial = None
        self._cassette_nfc_uid = None
        self._platform_serial = None
        self._platform_nfc_uid = None
        self._printer_serial = None
        self._software_version = None
        self.discriminator = None

        if cassette_serial is not None:
            self.cassette_serial = cassette_serial
        if cassette_nfc_uid is not None:
            self.cassette_nfc_uid = cassette_nfc_uid
        if platform_serial is not None:
            self.platform_serial = platform_serial
        if platform_nfc_uid is not None:
            self.platform_nfc_uid = platform_nfc_uid
        if printer_serial is not None:
            self.printer_serial = printer_serial
        if software_version is not None:
            self.software_version = software_version

    @property
    def cassette_serial(self):
        """Gets the cassette_serial of this PrintOrigin.  # noqa: E501


        :return: The cassette_serial of this PrintOrigin.  # noqa: E501
        :rtype: str
        """
        return self._cassette_serial

    @cassette_serial.setter
    def cassette_serial(self, cassette_serial):
        """Sets the cassette_serial of this PrintOrigin.


        :param cassette_serial: The cassette_serial of this PrintOrigin.  # noqa: E501
        :type: str
        """

        self._cassette_serial = cassette_serial

    @property
    def cassette_nfc_uid(self):
        """Gets the cassette_nfc_uid of this PrintOrigin.  # noqa: E501


        :return: The cassette_nfc_uid of this PrintOrigin.  # noqa: E501
        :rtype: str
        """
        return self._cassette_nfc_uid

    @cassette_nfc_uid.setter
    def cassette_nfc_uid(self, cassette_nfc_uid):
        """Sets the cassette_nfc_uid of this PrintOrigin.


        :param cassette_nfc_uid: The cassette_nfc_uid of this PrintOrigin.  # noqa: E501
        :type: str
        """

        self._cassette_nfc_uid = cassette_nfc_uid

    @property
    def platform_serial(self):
        """Gets the platform_serial of this PrintOrigin.  # noqa: E501


        :return: The platform_serial of this PrintOrigin.  # noqa: E501
        :rtype: str
        """
        return self._platform_serial

    @platform_serial.setter
    def platform_serial(self, platform_serial):
        """Sets the platform_serial of this PrintOrigin.


        :param platform_serial: The platform_serial of this PrintOrigin.  # noqa: E501
        :type: str
        """

        self._platform_serial = platform_serial

    @property
    def platform_nfc_uid(self):
        """Gets the platform_nfc_uid of this PrintOrigin.  # noqa: E501


        :return: The platform_nfc_uid of this PrintOrigin.  # noqa: E501
        :rtype: str
        """
        return self._platform_nfc_uid

    @platform_nfc_uid.setter
    def platform_nfc_uid(self, platform_nfc_uid):
        """Sets the platform_nfc_uid of this PrintOrigin.


        :param platform_nfc_uid: The platform_nfc_uid of this PrintOrigin.  # noqa: E501
        :type: str
        """

        self._platform_nfc_uid = platform_nfc_uid

    @property
    def printer_serial(self):
        """Gets the printer_serial of this PrintOrigin.  # noqa: E501


        :return: The printer_serial of this PrintOrigin.  # noqa: E501
        :rtype: str
        """
        return self._printer_serial

    @printer_serial.setter
    def printer_serial(self, printer_serial):
        """Sets the printer_serial of this PrintOrigin.


        :param printer_serial: The printer_serial of this PrintOrigin.  # noqa: E501
        :type: str
        """

        self._printer_serial = printer_serial

    @property
    def software_version(self):
        """Gets the software_version of this PrintOrigin.  # noqa: E501


        :return: The software_version of this PrintOrigin.  # noqa: E501
        :rtype: str
        """
        return self._software_version

    @software_version.setter
    def software_version(self, software_version):
        """Sets the software_version of this PrintOrigin.


        :param software_version: The software_version of this PrintOrigin.  # noqa: E501
        :type: str
        """

        self._software_version = software_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PrintOrigin):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PrintOrigin):
            return True

        return self.to_dict() != other.to_dict()
